@@ -158,12 +158,4 @@ class IBISMaster(object):
 			next_stop += " " * (4 - remainder)
 		
 		message = "zI%i%s" % (blocks, next_stop)
-		return self.send_message(message)
-
-def main():
-	import time
-	master = IBISMaster("/dev/ttyUSB0")
-	master.send_next_stop__003c("")
-
-if __name__ == "__main__":
-	main()
\ No newline at end of file
+		return self.send_message(message)
\ No newline at end of file
