@@ -2,11 +2,11 @@
 # See the LICENSE file for the full license.
 
 name = "pyIBIS"
-version = "1.4.4"
+version = "1.4.5"
 description = "A Python library for controlling IBIS displays"
 license = "AGPLv3"
 author = "Julian Metzler"
-author_email = "contact@mezgrman.de"
+author_email = "pyibis@mezgr.de"
 requires = []
 url = "https://github.com/Mezgrman/pyIBIS"
 keywords = "led sign message board effect library wrapper serial text display ibis vdv300 bus next stop train"
\ No newline at end of file
